Inventories
===========


Inventory Class
---------------

.. autoclass:: emiproc.inventories.Inventory
    :members:


Available Inventories 
---------------------

.. autoclass:: emiproc.inventories.tno.TNO_Inventory
    :special-members: __init__

.. autofunction:: emiproc.inventories.tno.read_tno_gridded_profiles

.. autoclass:: emiproc.inventories.edgar.EDGAR_Inventory
    :special-members: __init__

.. autoclass:: emiproc.inventories.swiss.SwissRasters
    :special-members: __init__

.. autofunction:: emiproc.inventories.swiss.read_prtr

.. autoclass:: emiproc.inventories.zurich.MapLuftZurich
    :special-members: __init__

.. autoclass:: emiproc.inventories.EmiprocNetCDF
    :special-members: __init__

.. autoclass:: emiproc.inventories.gfas.GFAS_Inventory
    :special-members: __init__

.. autoclass:: emiproc.inventories.gfed.GFED4_Inventory
    :special-members: __init__

.. autoclass:: emiproc.inventories.lpjguess.LPJ_GUESS_Inventory
    :special-members: __init__

.. autoclass:: emiproc.inventories.saunois.SaunoisInventory
    :special-members: __init__

.. autoclass:: emiproc.inventories.gral.GralInventory
    :special-members: __init__